==> JDFLibJ-2.1.7.2-sources.jar: org/cip4/jdflib/auto/JDFAutoColorControlStrip.java <==
/*
 * The CIP4 Software License, Version 1.0
 *
 *
 * Copyright (c) 2001-2020 The International Cooperation for the Integration of
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
  *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG
 * copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *
 *
 */

package org.cip4.jdflib.auto;

import java.util.Collection;

import org.apache.xerces.dom.CoreDocumentImpl;
import org.cip4.jdflib.core.AtrInfoTable;
import org.cip4.jdflib.core.AttributeInfo;
import org.cip4.jdflib.core.AttributeName;
import org.cip4.jdflib.core.ElemInfoTable;
import org.cip4.jdflib.core.ElementInfo;
import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.JDFCoreConstants;
import org.cip4.jdflib.datatypes.JDFXYPair;
import org.cip4.jdflib.resource.JDFPatch;
import org.cip4.jdflib.resource.JDFResource;
import org.cip4.jdflib.resource.process.JDFCIELABMeasuringField;
import org.cip4.jdflib.resource.process.JDFDensityMeasuringField;
import org.cip4.jdflib.resource.process.JDFSeparationSpec;

/**
 *****************************************************************************
 * class JDFAutoColorControlStrip : public JDFResource
 *****************************************************************************
 *
 */

public abstract class JDFAutoColorControlStrip extends JDFResource
{

	private static final long serialVersionUID = 1L;

	private static AtrInfoTable[] atrInfoTable = new AtrInfoTable[4];
	static
	{
		atrInfoTable[0] = new AtrInfoTable(AttributeName.CENTER, 0x33333333, AttributeInfo.EnumAttributeType.XYPair, null, null);
		atrInfoTable[1] = new AtrInfoTable(AttributeName.ROTATION, 0x33333333, AttributeInfo.EnumAttributeType.double_, null, null);
		atrInfoTable[2] = new AtrInfoTable(AttributeName.SIZE, 0x33333333, AttributeInfo.EnumAttributeType.XYPair, null, null);
		atrInfoTable[3] = new AtrInfoTable(AttributeName.STRIPTYPE, 0x33333333, AttributeInfo.EnumAttributeType.string, null, null);
	}

	@Override
	protected AttributeInfo getTheAttributeInfo()
	{
		return super.getTheAttributeInfo().updateReplace(atrInfoTable);
	}

	private static ElemInfoTable[] elemInfoTable = new ElemInfoTable[4];
	static
	{
		elemInfoTable[0] = new ElemInfoTable(ElementName.CIELABMEASURINGFIELD, 0x33333331);
		elemInfoTable[1] = new ElemInfoTable(ElementName.DENSITYMEASURINGFIELD, 0x33333331);
		elemInfoTable[2] = new ElemInfoTable(ElementName.PATCH, 0x31111111);
		elemInfoTable[3] = new ElemInfoTable(ElementName.SEPARATIONSPEC, 0x33331111);
	}

	@Override
	protected ElementInfo getTheElementInfo()
	{
		return super.getTheElementInfo().updateReplace(elemInfoTable);
	}

	/**
	 * Constructor for JDFAutoColorControlStrip
	 *
	 * @param myOwnerDocument
	 * @param qualifiedName
	 */
	protected JDFAutoColorControlStrip(CoreDocumentImpl myOwnerDocument, String qualifiedName)
	{
		super(myOwnerDocument, qualifiedName);
	}

	/**
	 * Constructor for JDFAutoColorControlStrip
	 *
	 * @param myOwnerDocument
	 * @param myNamespaceURI
	 * @param qualifiedName
	 */
	protected JDFAutoColorControlStrip(CoreDocumentImpl myOwnerDocument, String myNamespaceURI, String qualifiedName)
	{
		super(myOwnerDocument, myNamespaceURI, qualifiedName);
	}

	/**
	 * Constructor for JDFAutoColorControlStrip
	 *
	 * @param myOwnerDocument
	 * @param myNamespaceURI
	 * @param qualifiedName
	 * @param myLocalName
	 */
	protected JDFAutoColorControlStrip(CoreDocumentImpl myOwnerDocument, String myNamespaceURI, String qualifiedName, String myLocalName)
	{
		super(myOwnerDocument, myNamespaceURI, qualifiedName, myLocalName);
	}

	/**
	 * @return true if ok
	 */
	@Override
	public boolean init()
	{
		final boolean bRet = super.init();
		setResourceClass(JDFResource.EnumResourceClass.Parameter);
		return bRet;
	}

	/**
	 * @return the resource Class
	 */
	@Override
	public EnumResourceClass getValidClass()
	{
		return JDFResource.EnumResourceClass.Parameter;
	}

	/* ************************************************************************
	 * Attribute getter / setter
	 * ************************************************************************
	 */

	/* ---------------------------------------------------------------------
	Methods for Attribute Center
	--------------------------------------------------------------------- */
	/**
	 * (36) set attribute Center
	 *
	 * @param value the value to set the attribute to
	 */
	public void setCenter(JDFXYPair value)
	{
		setAttribute(AttributeName.CENTER, value, null);
	}

	/**
	 * (20) get JDFXYPair attribute Center
	 *
	 * @return JDFXYPair the value of the attribute, null if a the attribute value is not a valid to create a JDFXYPair
	 */
	public JDFXYPair getCenter()
	{
		final String strAttrName = getAttribute(AttributeName.CENTER, null, null);
		final JDFXYPair nPlaceHolder = JDFXYPair.createXYPair(strAttrName);
		return nPlaceHolder;
	}

	/* ---------------------------------------------------------------------
	Methods for Attribute Rotation
	--------------------------------------------------------------------- */
	/**
	 * (36) set attribute Rotation
	 *
	 * @param value the value to set the attribute to
	 */
	public void setRotation(double value)
	{
		setAttribute(AttributeName.ROTATION, value, null);
	}

	/**
	 * (17) get double attribute Rotation
	 *
	 * @return double the value of the attribute
	 */
	public double getRotation()
	{
		return getRealAttribute(AttributeName.ROTATION, null, 0.0);
	}

	/* ---------------------------------------------------------------------
	Methods for Attribute Size
	--------------------------------------------------------------------- */
	/**
	 * (36) set attribute Size
	 *
	 * @param value the value to set the attribute to
	 */
	public void setSize(JDFXYPair value)
	{
		setAttribute(AttributeName.SIZE, value, null);
	}

	/**
	 * (20) get JDFXYPair attribute Size
	 *
	 * @return JDFXYPair the value of the attribute, null if a the attribute value is not a valid to create a JDFXYPair
	 */
	public JDFXYPair getSize()
	{
		final String strAttrName = getAttribute(AttributeName.SIZE, null, null);
		final JDFXYPair nPlaceHolder = JDFXYPair.createXYPair(strAttrName);
		return nPlaceHolder;
	}

	/* ---------------------------------------------------------------------
	Methods for Attribute StripType
	--------------------------------------------------------------------- */
	/**
	 * (36) set attribute StripType
	 *
	 * @param value the value to set the attribute to
	 */
	public void setStripType(String value)
	{
		setAttribute(AttributeName.STRIPTYPE, value, null);
	}

	/**
	 * (23) get String attribute StripType
	 *
	 * @return the value of the attribute
	 */
	public String getStripType()
	{
		return getAttribute(AttributeName.STRIPTYPE, null, JDFCoreConstants.EMPTYSTRING);
	}

	/* ***********************************************************************
	 * Element getter / setter
	 * ***********************************************************************
	 */

	/**
	 * (26) getCreateCIELABMeasuringField
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFCIELABMeasuringField the element
	 */
	public JDFCIELABMeasuringField getCreateCIELABMeasuringField(int iSkip)
	{
		return (JDFCIELABMeasuringField) getCreateElement_JDFElement(ElementName.CIELABMEASURINGFIELD, null, iSkip);
	}

	/**
	 * (27) const get element CIELABMeasuringField
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFCIELABMeasuringField the element default is getCIELABMeasuringField(0)
	 */
	public JDFCIELABMeasuringField getCIELABMeasuringField(int iSkip)
	{
		return (JDFCIELABMeasuringField) getElement(ElementName.CIELABMEASURINGFIELD, null, iSkip);
	}

	/**
	 * Get all CIELABMeasuringField from the current element
	 *
	 * @return Collection<JDFCIELABMeasuringField>, null if none are available
	 */
	public Collection<JDFCIELABMeasuringField> getAllCIELABMeasuringField()
	{
		return getChildArrayByClass(JDFCIELABMeasuringField.class, false, 0);
	}

	/**
	 * (30) append element CIELABMeasuringField
	 *
	 * @return JDFCIELABMeasuringField the element
	 */
	public JDFCIELABMeasuringField appendCIELABMeasuringField()
	{
		return (JDFCIELABMeasuringField) appendElement(ElementName.CIELABMEASURINGFIELD, null);
	}

	/**
	 * (26) getCreateDensityMeasuringField
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFDensityMeasuringField the element
	 */
	public JDFDensityMeasuringField getCreateDensityMeasuringField(int iSkip)
	{
		return (JDFDensityMeasuringField) getCreateElement_JDFElement(ElementName.DENSITYMEASURINGFIELD, null, iSkip);
	}

	/**
	 * (27) const get element DensityMeasuringField
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFDensityMeasuringField the element default is getDensityMeasuringField(0)
	 */
	public JDFDensityMeasuringField getDensityMeasuringField(int iSkip)
	{
		return (JDFDensityMeasuringField) getElement(ElementName.DENSITYMEASURINGFIELD, null, iSkip);
	}

	/**
	 * Get all DensityMeasuringField from the current element
	 *
	 * @return Collection<JDFDensityMeasuringField>, null if none are available
	 */
	public Collection<JDFDensityMeasuringField> getAllDensityMeasuringField()
	{
		return getChildArrayByClass(JDFDensityMeasuringField.class, false, 0);
	}

	/**
	 * (30) append element DensityMeasuringField
	 *
	 * @return JDFDensityMeasuringField the element
	 */
	public JDFDensityMeasuringField appendDensityMeasuringField()
	{
		return (JDFDensityMeasuringField) appendElement(ElementName.DENSITYMEASURINGFIELD, null);
	}

	/**
	 * (31) create inter-resource link to refTarget
	 *
	 * @param refTarget the element that is referenced
	 */
	public void refDensityMeasuringField(JDFDensityMeasuringField refTarget)
	{
		refElement(refTarget);
	}

	/**
	 * (26) getCreatePatch
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFPatch the element
	 */
	public JDFPatch getCreatePatch(int iSkip)
	{
		return (JDFPatch) getCreateElement_JDFElement(ElementName.PATCH, null, iSkip);
	}

	/**
	 * (27) const get element Patch
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFPatch the element default is getPatch(0)
	 */
	public JDFPatch getPatch(int iSkip)
	{
		return (JDFPatch) getElement(ElementName.PATCH, null, iSkip);
	}

	/**
	 * Get all Patch from the current element
	 *
	 * @return Collection<JDFPatch>, null if none are available
	 */
	public Collection<JDFPatch> getAllPatch()
	{
		return getChildArrayByClass(JDFPatch.class, false, 0);
	}

	/**
	 * (30) append element Patch
	 *
	 * @return JDFPatch the element
	 */
	public JDFPatch appendPatch()
	{
		return (JDFPatch) appendElement(ElementName.PATCH, null);
	}

	/**
	 * (26) getCreateSeparationSpec
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFSeparationSpec the element
	 */
	public JDFSeparationSpec getCreateSeparationSpec(int iSkip)
	{
		return (JDFSeparationSpec) getCreateElement_JDFElement(ElementName.SEPARATIONSPEC, null, iSkip);
	}

	/**
	 * (27) const get element SeparationSpec
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFSeparationSpec the element default is getSeparationSpec(0)
	 */
	public JDFSeparationSpec getSeparationSpec(int iSkip)
	{
		return (JDFSeparationSpec) getElement(ElementName.SEPARATIONSPEC, null, iSkip);
	}

	/**
	 * Get all SeparationSpec from the current element
	 *
	 * @return Collection<JDFSeparationSpec>, null if none are available
	 */
	public Collection<JDFSeparationSpec> getAllSeparationSpec()
	{
		return getChildArrayByClass(JDFSeparationSpec.class, false, 0);
	}

	/**
	 * (30) append element SeparationSpec
	 *
	 * @return JDFSeparationSpec the element
	 */
	public JDFSeparationSpec appendSeparationSpec()
	{
		return (JDFSeparationSpec) appendElement(ElementName.SEPARATIONSPEC, null);
	}

}

==> JDFLibJ-2.1.8.1-sources.jar: org/cip4/jdflib/auto/JDFAutoColorControlStrip.java <==
/*
 * The CIP4 Software License, Version 1.0
 *
 *
 * Copyright (c) 2001-2024 The International Cooperation for the Integration of
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
  *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG
 * copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *
 *
 */

package org.cip4.jdflib.auto;

import java.util.Collection;

import org.apache.xerces.dom.CoreDocumentImpl;
import org.cip4.jdflib.core.AtrInfoTable;
import org.cip4.jdflib.core.AttributeInfo;
import org.cip4.jdflib.core.AttributeName;
import org.cip4.jdflib.core.ElemInfoTable;
import org.cip4.jdflib.core.ElementInfo;
import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.JDFCoreConstants;
import org.cip4.jdflib.datatypes.JDFXYPair;
import org.cip4.jdflib.resource.JDFPatch;
import org.cip4.jdflib.resource.JDFResource;
import org.cip4.jdflib.resource.process.JDFCIELABMeasuringField;
import org.cip4.jdflib.resource.process.JDFDensityMeasuringField;
import org.cip4.jdflib.resource.process.JDFSeparationSpec;

/**
 *****************************************************************************
 * class JDFAutoColorControlStrip : public JDFResource
 *****************************************************************************
 * 
 */

public abstract class JDFAutoColorControlStrip extends JDFResource
{

	private static final long serialVersionUID = 1L;

	private static AtrInfoTable[] atrInfoTable = new AtrInfoTable[4];
	static
	{
		atrInfoTable[0] = new AtrInfoTable(AttributeName.CENTER, 0x3333333333l, AttributeInfo.EnumAttributeType.XYPair, null, null);
		atrInfoTable[1] = new AtrInfoTable(AttributeName.ROTATION, 0x3333333333l, AttributeInfo.EnumAttributeType.double_, null, null);
		atrInfoTable[2] = new AtrInfoTable(AttributeName.SIZE, 0x3333333333l, AttributeInfo.EnumAttributeType.XYPair, null, null);
		atrInfoTable[3] = new AtrInfoTable(AttributeName.STRIPTYPE, 0x3333333333l, AttributeInfo.EnumAttributeType.string, null, null);
	}

	@Override
	protected AttributeInfo getTheAttributeInfo()
	{
		return super.getTheAttributeInfo().updateReplace(atrInfoTable);
	}

	private static ElemInfoTable[] elemInfoTable = new ElemInfoTable[4];
	static
	{
		elemInfoTable[0] = new ElemInfoTable(ElementName.CIELABMEASURINGFIELD, 0x3333333331l);
		elemInfoTable[1] = new ElemInfoTable(ElementName.DENSITYMEASURINGFIELD, 0x3333333331l);
		elemInfoTable[2] = new ElemInfoTable(ElementName.PATCH, 0x3331111111l);
		elemInfoTable[3] = new ElemInfoTable(ElementName.SEPARATIONSPEC, 0x3333331111l);
	}

	@Override
	protected ElementInfo getTheElementInfo()
	{
		return super.getTheElementInfo().updateReplace(elemInfoTable);
	}

	/**
	 * Constructor for JDFAutoColorControlStrip
	 *
	 * @param myOwnerDocument
	 * @param qualifiedName
	 */
	protected JDFAutoColorControlStrip(CoreDocumentImpl myOwnerDocument, String qualifiedName)
	{
		super(myOwnerDocument, qualifiedName);
	}

	/**
	 * Constructor for JDFAutoColorControlStrip
	 *
	 * @param myOwnerDocument
	 * @param myNamespaceURI
	 * @param qualifiedName
	 */
	protected JDFAutoColorControlStrip(CoreDocumentImpl myOwnerDocument, String myNamespaceURI, String qualifiedName)
	{
		super(myOwnerDocument, myNamespaceURI, qualifiedName);
	}

	/**
	 * Constructor for JDFAutoColorControlStrip
	 *
	 * @param myOwnerDocument
	 * @param myNamespaceURI
	 * @param qualifiedName
	 * @param myLocalName
	 */
	protected JDFAutoColorControlStrip(CoreDocumentImpl myOwnerDocument, String myNamespaceURI, String qualifiedName, String myLocalName)
	{
		super(myOwnerDocument, myNamespaceURI, qualifiedName, myLocalName);
	}

	/**
	 * @return true if ok
	 */
	@Override
	public boolean init()
	{
		final boolean bRet = super.init();
		setResourceClass(JDFResource.EnumResourceClass.Parameter);
		return bRet;
	}

	/**
	 * @return the resource Class
	 */
	@Override
	public EnumResourceClass getValidClass()
	{
		return JDFResource.EnumResourceClass.Parameter;
	}

	/*
	 * ************************************************************************ Attribute getter / setter ************************************************************************
	 */

	/*
	 * --------------------------------------------------------------------- Methods for Attribute Center ---------------------------------------------------------------------
	 */
	/**
	 * (36) set attribute Center
	 *
	 * @param value the value to set the attribute to
	 */
	public void setCenter(JDFXYPair value)
	{
		setAttribute(AttributeName.CENTER, value, null);
	}

	/**
	 * (20) get JDFXYPair attribute Center
	 *
	 * @return JDFXYPair the value of the attribute, null if a the attribute value is not a valid to create a JDFXYPair
	 */
	public JDFXYPair getCenter()
	{
		final String strAttrName = getAttribute(AttributeName.CENTER, null, null);
		final JDFXYPair nPlaceHolder = JDFXYPair.createXYPair(strAttrName);
		return nPlaceHolder;
	}

	/*
	 * --------------------------------------------------------------------- Methods for Attribute Rotation ---------------------------------------------------------------------
	 */
	/**
	 * (36) set attribute Rotation
	 *
	 * @param value the value to set the attribute to
	 */
	public void setRotation(double value)
	{
		setAttribute(AttributeName.ROTATION, value, null);
	}

	/**
	 * (17) get double attribute Rotation
	 *
	 * @return double the value of the attribute
	 */
	public double getRotation()
	{
		return getRealAttribute(AttributeName.ROTATION, null, 0.0);
	}

	/*
	 * --------------------------------------------------------------------- Methods for Attribute Size ---------------------------------------------------------------------
	 */
	/**
	 * (36) set attribute Size
	 *
	 * @param value the value to set the attribute to
	 */
	public void setSize(JDFXYPair value)
	{
		setAttribute(AttributeName.SIZE, value, null);
	}

	/**
	 * (20) get JDFXYPair attribute Size
	 *
	 * @return JDFXYPair the value of the attribute, null if a the attribute value is not a valid to create a JDFXYPair
	 */
	public JDFXYPair getSize()
	{
		final String strAttrName = getAttribute(AttributeName.SIZE, null, null);
		final JDFXYPair nPlaceHolder = JDFXYPair.createXYPair(strAttrName);
		return nPlaceHolder;
	}

	/*
	 * --------------------------------------------------------------------- Methods for Attribute StripType ---------------------------------------------------------------------
	 */
	/**
	 * (36) set attribute StripType
	 *
	 * @param value the value to set the attribute to
	 */
	public void setStripType(String value)
	{
		setAttribute(AttributeName.STRIPTYPE, value, null);
	}

	/**
	 * (23) get String attribute StripType
	 *
	 * @return the value of the attribute
	 */
	public String getStripType()
	{
		return getAttribute(AttributeName.STRIPTYPE, null, JDFCoreConstants.EMPTYSTRING);
	}

	/*
	 * *********************************************************************** Element getter / setter ***********************************************************************
	 */

	/**
	 * (26) getCreateCIELABMeasuringField
	 * 
	 * @param iSkip number of elements to skip
	 * @return JDFCIELABMeasuringField the element
	 */
	public JDFCIELABMeasuringField getCreateCIELABMeasuringField(int iSkip)
	{
		return (JDFCIELABMeasuringField) getCreateElement_JDFElement(ElementName.CIELABMEASURINGFIELD, null, iSkip);
	}

	/**
	 * (27) const get element CIELABMeasuringField
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFCIELABMeasuringField the element default is getCIELABMeasuringField(0)
	 */
	public JDFCIELABMeasuringField getCIELABMeasuringField(int iSkip)
	{
		return (JDFCIELABMeasuringField) getElement(ElementName.CIELABMEASURINGFIELD, null, iSkip);
	}

	/**
	 * Get all CIELABMeasuringField from the current element
	 * 
	 * @return Collection<JDFCIELABMeasuringField>, null if none are available
	 */
	public Collection<JDFCIELABMeasuringField> getAllCIELABMeasuringField()
	{
		return getChildArrayByClass(JDFCIELABMeasuringField.class, false, 0);
	}

	/**
	 * (30) append element CIELABMeasuringField
	 *
	 * @return JDFCIELABMeasuringField the element
	 */
	public JDFCIELABMeasuringField appendCIELABMeasuringField()
	{
		return (JDFCIELABMeasuringField) appendElement(ElementName.CIELABMEASURINGFIELD, null);
	}

	/**
	 * (26) getCreateDensityMeasuringField
	 * 
	 * @param iSkip number of elements to skip
	 * @return JDFDensityMeasuringField the element
	 */
	public JDFDensityMeasuringField getCreateDensityMeasuringField(int iSkip)
	{
		return (JDFDensityMeasuringField) getCreateElement_JDFElement(ElementName.DENSITYMEASURINGFIELD, null, iSkip);
	}

	/**
	 * (27) const get element DensityMeasuringField
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFDensityMeasuringField the element default is getDensityMeasuringField(0)
	 */
	public JDFDensityMeasuringField getDensityMeasuringField(int iSkip)
	{
		return (JDFDensityMeasuringField) getElement(ElementName.DENSITYMEASURINGFIELD, null, iSkip);
	}

	/**
	 * Get all DensityMeasuringField from the current element
	 * 
	 * @return Collection<JDFDensityMeasuringField>, null if none are available
	 */
	public Collection<JDFDensityMeasuringField> getAllDensityMeasuringField()
	{
		return getChildArrayByClass(JDFDensityMeasuringField.class, false, 0);
	}

	/**
	 * (30) append element DensityMeasuringField
	 *
	 * @return JDFDensityMeasuringField the element
	 */
	public JDFDensityMeasuringField appendDensityMeasuringField()
	{
		return (JDFDensityMeasuringField) appendElement(ElementName.DENSITYMEASURINGFIELD, null);
	}

	/**
	 * (31) create inter-resource link to refTarget
	 *
	 * @param refTarget the element that is referenced
	 */
	public void refDensityMeasuringField(JDFDensityMeasuringField refTarget)
	{
		refElement(refTarget);
	}

	/**
	 * (26) getCreatePatch
	 * 
	 * @param iSkip number of elements to skip
	 * @return JDFPatch the element
	 */
	public JDFPatch getCreatePatch(int iSkip)
	{
		return (JDFPatch) getCreateElement_JDFElement(ElementName.PATCH, null, iSkip);
	}

	/**
	 * (27) const get element Patch
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFPatch the element default is getPatch(0)
	 */
	public JDFPatch getPatch(int iSkip)
	{
		return (JDFPatch) getElement(ElementName.PATCH, null, iSkip);
	}

	/**
	 * Get all Patch from the current element
	 * 
	 * @return Collection<JDFPatch>, null if none are available
	 */
	public Collection<JDFPatch> getAllPatch()
	{
		return getChildArrayByClass(JDFPatch.class, false, 0);
	}

	/**
	 * (30) append element Patch
	 *
	 * @return JDFPatch the element
	 */
	public JDFPatch appendPatch()
	{
		return (JDFPatch) appendElement(ElementName.PATCH, null);
	}

	/**
	 * (26) getCreateSeparationSpec
	 * 
	 * @param iSkip number of elements to skip
	 * @return JDFSeparationSpec the element
	 */
	public JDFSeparationSpec getCreateSeparationSpec(int iSkip)
	{
		return (JDFSeparationSpec) getCreateElement_JDFElement(ElementName.SEPARATIONSPEC, null, iSkip);
	}

	/**
	 * (27) const get element SeparationSpec
	 *
	 * @param iSkip number of elements to skip
	 * @return JDFSeparationSpec the element default is getSeparationSpec(0)
	 */
	public JDFSeparationSpec getSeparationSpec(int iSkip)
	{
		return (JDFSeparationSpec) getElement(ElementName.SEPARATIONSPEC, null, iSkip);
	}

	/**
	 * Get all SeparationSpec from the current element
	 * 
	 * @return Collection<JDFSeparationSpec>, null if none are available
	 */
	public Collection<JDFSeparationSpec> getAllSeparationSpec()
	{
		return getChildArrayByClass(JDFSeparationSpec.class, false, 0);
	}

	/**
	 * (30) append element SeparationSpec
	 *
	 * @return JDFSeparationSpec the element
	 */
	public JDFSeparationSpec appendSeparationSpec()
	{
		return (JDFSeparationSpec) appendElement(ElementName.SEPARATIONSPEC, null);
	}

}
